/**************************************************************
            ==================================
            Star Wars - The POV-Ray Collection
            ==================================

<filename>.INC - 3D model description file for use with the
Persistence of Vision Ray-Tracer, v3.0

POV-Ray code copyright (c) 1997 D M Beattie

This model is provided for personal use only. Any use of this
model for commercial gain or profit is strictly forbidden -
please see the accompanying README.TXT and Conditions of Use
before using or distributing this model.

'Star Wars' and all associated images, designs and trademarks,
(including the designs of the vehicles and objects depicted in
the Star Wars POV-Ray Collection, except where otherwise
stated) are copyright (c) 1997 Lucasfilm Ltd.

**************************************************************/

// R2D2.INC - R2-D2 model definition for POV-Ray v3.0

#declare R2_Tex1 = texture { //White plastic texture
  pigment {colour rgb 1}
}

#declare R2_Tex2 = texture { //Black plastic texture
  pigment {colour rgb 0.05}
}

#declare R2_Tex3 = texture { //Silver metal texture
  pigment {colour rgb <0.90, 0.91, 0.98>}
  finish {
    metallic
    ambient 0.2
    diffuse 0.7
    brilliance 6
    reflection 0.25
    specular 0.75
    roughness 0.005
  }
}

#declare R2_Tex4 = texture {
  pigment {colour rgb 0.2}
}

#declare R2_Sensor1 = object {
  union {
    object {cylinder {<0,0,-0.01>, <0,0,0.001>, 0.06} texture {R2_Tex2}}
    object {
      difference {
        object {cylinder {<0,0,0>, <0,0,0.02>, 0.05}}
        object {cylinder {<0,0,0>, <0,0,0.03>, 0.045}}
      }
      texture {R2_Tex4}
    }
    object {
      sphere {<0,0,0>, 0.04}
      scale <1,1,0.25>
      translate <0,0,0.015>
      texture {
        pigment {colour rgb <0,0,0.1>}
        finish {specular 1 roughness 0.01 reflection 0.7}
      }
    }
  }
}
#declare R2_Sensor2 = object {
  union {
    object {
      difference {
        object {cylinder {<0,0,-0.02>, <0,0,0.001>, 0.04}}
        object {cylinder {<0,0,-0.02>, <0,0,0.002>, 0.0375}}

      }
      texture {R2_Tex2}
    }
    object {
      cylinder {<0,0,-0.02>, <0,0,0.0005>, 0.0375}
      texture {
        pigment {
          gradient <1,0,0>
          colour_map {
            [0 colour rgb <0.5,0.5,1>]
            [1 colour rgb <1.0,0,0>]
          }
          scale 0.0375*2
          translate <-0.0375,0,0>
        }
        finish {ambient 1}
      }
    }
  }
}

#declare R2_Sensor3 = object {
  union {
    object {
      difference {
        object {box {<-0.1, -0.075, -0.1>, <0.1, 0.075, 0.1>}}
        object {cylinder {<0.02,0.01,-0.2>, <0.02,0.01,0.2>, 0.05}}
        object {sphere {<0,0,-0.5>, 0.51} inverse}
      }
      texture {R2_Tex2}
    }
    object {
      sphere {<0,0,0>, 0.05}
      scale <1,1,0.25>
      translate <0.02, 0.01, 0>
      texture {
        pigment {colour rgb 0.1}
        finish {specular 1 roughness 0.01 reflection 0.6}
      }
    }
  }
}

#declare R2D2Head = object {
  union {
    object {
      intersection {
        object {sphere {<0,0,0>, 0.5}}
        object {plane {<0,-1,0>, 0}}
      }
      texture {
        material_map {
          gif "r2head.gif" map_type 1
          texture {R2_Tex3}
          texture {R2_Tex3 pigment {colour rgb <0,0,0.6>}}
          texture {R2_Tex3 pigment {colour rgb 0.1}}
        }
        rotate <0,-10,0>
      }
    }
    object {
      R2_Sensor1
      translate <0,0,0.5>
      rotate <-16,0,0>
      rotate <0,-28,0>
    }
    object {
      R2_Sensor2
      translate <0,0,0.5>
      rotate <-12,0,0>
      rotate <0,-8,0>
    }
    object {
      R2_Sensor3
      translate <0,0,0.5>
      rotate <-30,0,0>
      rotate <0,-2,0>
    }
  }
}
#declare R2D2LegA = object {
  union {
    object {cylinder {<0.5, 1.75, 0>, <0.6, 1.75, 0>, 0.2}}
    object {box {<0.5, 1.45, -0.2>, <0.6, 1.75, 0.2>}}
    object {
      intersection {
        object {cone {<0,1.35,0>, 0.12, <0,1.45,0>, 0.2} scale <100,1,1> translate <0.5,0,0>}
        object {box {<0.5,-1,-1>, <0.6, 2, 2>}}
      }
    }
    object {
      intersection {
        object {cone {<0,1.3,0>, 0.12, <0,1.45,0>, 0.2} scale <100,1,1> translate <0.5,0,0>}
        object {box {<0.525,-1,-1>, <0.549, 2, 2>}}
      }
    }
    object {box {<0.5, 0.75, -0.13>, <0.549, 1.4, 0.13>}}
  }
  texture {R2_Tex1}
}

#declare R2_Foot = object {
  union {
    object { // Tops of feet
      intersection {
        object {cone {<0,0.499,0>, 0.15, <0,0.741,0>, 0.055} scale <1,1,100>}
        object {cone {<0,0.5,0>, 0.275, <0,0.74,0>, 0.16} scale <100,1,1>}
      }
      texture {R2_Tex1}
    }
    object { // Detail on sides of feet
      intersection {
        object {cone {<0,0.499,0>, 0.145, <0,0.741,0>, 0.075} scale <1,1,100>}
        object {cylinder {<-1,0.6, 0>, <1, 0.6, 0>, 0.09}}
      }
      texture {R2_Tex1}
    }
    object {
      intersection { // Undersides of feet
        object {cone {<0,0.499,0>, 0.15, <0,0.449,0>, 0.085} scale <1,1,100>}
        object {cone {<0,0.5,0>, 0.275, <0,0.45,0>, 0.2} scale <100,1,1>}
      }
      texture {R2_Tex1}
    }
    object {
      union {
        object {cylinder {<-0.075, 0.45, 0.15>, <0.075, 0.45, 0.15>, 0.025}}
        object {cylinder {<-0.075, 0.45, -0.15>, <0.075, 0.45, -0.15>, 0.025}}
        object {box {<-0.075, 0.425, -0.15>, <0.075, 0.475, 0.15>}}
      }
      texture {R2_Tex2 normal {bumps 0.5 scale 0.01}}
    }
  }
}

#declare R2D2Leg = object {
  union {
    object {
      difference {
        object {R2D2LegA}
        object {cylinder {<0.549, 1.75, 0>, <0.65, 1.75, 0>, 0.1} texture {R2_Tex3}}
        object {
          intersection {
            object {cone {<0,1.6,0>, 0.12, <0,1.75,0>, 0} scale <100,1,1> translate <0.5,0,0>}
            object {box {<0.55, -2, -2>, <0.65, 2, 2>}}
          }
          texture {R2_Tex2}
        }
        object {box {<0.55,1.35,-0.12>, <0.65, 1.6, 0.12>} texture {R2_Tex2}}
      }
    }
    object {box {<0.59,1.45,-0.175>, <0.61, 1.75, -0.125>} texture {R2_Tex3}}
    object {box {<0.59,1.6,0.125>, <0.61, 1.65, 0.175>} texture {R2_Tex3}}
    object {box {<0.59,1.7,0.125>, <0.61, 1.75, 0.175>} texture {R2_Tex3}}
    object {box {<0.55, 0.75, -0.05>, <0.56, 1.35, 0.05>} texture {R2_Tex2}}
    object {
      intersection {
        object {cone {<0.55, 1.35, 0>, 0.03, <0.55, 1.45, 0>, 0.07} scale <1,1,10>}
        object {box {<0.5, 1.3, -0.07>, <0.7, 1.5, 0.07>}}
      }
      texture {R2_Tex2}
    }
    object {
      intersection {
        object {cone {<0.55, 1.35, 0>, 0.03, <0.55, 1.55, 0>, 0.05} scale <1,1,10>}
        object {box {<0.5, 1.3, -0.07>, <0.7, 1.5, 0.07>}}
      }
      texture {R2_Tex2}
    }
    object {cone {<0.55, 1.25, 0>, 0.02, <0.55, 1.35, 0>, 0.03} texture {R2_Tex3}}
    object {cylinder {<0.55, 0.75, 0>, <0.55, 1.25, 0>, 0.02} texture {R2_Tex3}}
    object {box {<0.475, 0.75, -0.15>, <0.575, 0.95, 0.15>} texture {R2_Tex1}}
    object {R2_Foot translate <-0.525, 0,0>}
  }
}


#declare R2D2Body = object {
  union {
    object {
      cylinder {<0,1,0>, <0,1.99,0>, 0.5}
      texture {
        material_map {
          gif "r2d2body.gif" map_type 2 once
          texture {
            pigment {
              gradient <0,1,>
              colour_map {
                [0 colour rgb 0.75]
                [0.75 colour rgb 0.75]
                [0.75 colour rgb 0]
                [1.0 colour rgb 0]
              }
              scale 0.01
            }
          }
          texture {R2_Tex3 pigment {colour rgb <0,0,0.6>}}
          texture {R2_Tex1 pigment {colour rgb 0.2}}
          texture {R2_Tex1}
        }
        translate <0,1,0>
        rotate <0,90,0>
      }
    }
    object {
      difference {
        object {cone {<0,0.8,0>, 0.35, <0,1,0>, 0.4} texture {R2_Tex1}}
        object {cylinder {<0,0.75,0>, <0,1,0>, 0.326}}
      }
    }
    object {
      difference {
        object {cone {<0,0.8,0>, 0.35, <0,1,0>, 0.45} texture {R2_Tex1}}
        object {
          union {
            object {cylinder {<0,0.75,0>, <0,1,0>, 0.325}}
            #declare Count = 1
            #while (Count<360)
            object {
              box {<-0.05,0.825,0>, <0.05, 0.95, 0.5>}
              rotate <0,Count,0>
            }
            #declare Count = Count + 20
            #end
          }
        }
      }
    }
  }
}

#declare R2D2 = object {
  union {
    object {R2D2Head translate <0,2,0>}
    object {R2D2Body}
    object {R2D2Leg scale <1,1,1>}
    object {R2D2Leg scale <-1,1,1>}
  }
  translate <0,-0.425,0>
  scale 0.4
}
